# Contributors

## Leader:
+ Can He (Sany, National University of Singapore, Singapore)
  Email: sanyhew1097618435@163.com

## Technical Group:
+ Jianming Zhao (Jamie, Jilin University, Changchun, China)
+ Jianhao Sun (Jin, China University of Geosciences, Wuhan, China)
+ Kaixin Zheng (Hayne, Sun Yat-sen University, China)
+ Jianing Wang (National University of Singapore, Singapore)
+ Yongkang Chang (Kill-virus, Langzhou University, China)
+ Mengying Ye (Mary, Jilin University, China)
+ Mengqi Gao (China University of Geosciences, Beijing, China)

## Product Group:
+ Yang Lyu (Daisy, Zhejiang University, China)
+ Wenyu Zhao (Molly, Zhejiang University, China)
+ Keran Li (Kirk, Chengdu University of Technology, China)
+ Aixiwake·Janganuer (Ayshuak, Sun Yat-sen University, China)
+ Bailun Jiang (EPSI / Lille University, France)
+ Yucheng Yan (Andy, University of Sydney, Australia)
+ Ruitao Chang (China University of Geosciences Beijing, China)
+ Zhenglin Xu (Garry, Jilin University, China)

## Former Contributors:
+ Shengxin Wang (Samson, Lanzhou University, China)
+ Qiuhao Zhao (Brad, Zhejiang University, China)
+ Anzhou Li (Andrian, Zhejiang University, China)
+ Dan Hu (Notre Dame University, United States)
+ Xunxin Liu (Tante, China University of Geosciences, Wuhan, China)
+ Fang Li (liv, Shenzhen University, China)
+ Xin Li (The University of Manchester, United Kingdom)
+ Ting Liu (Kira, Sun Yat-sen University, China)
+ Xirui Zhu (Rae, University of York, United Kingdom)
